# -*- coding: utf-8 -*-

import os
import subprocess as subp
from sklearn_porter import Porter
from ..utils.DependencyChecker import DependencyChecker as Checker


class C(Checker):

    DEPENDENCIES = ['mkdir', 'gcc']

    # noinspection PyPep8Naming
    def setUp(self):
        super(C, self).setUp()
        self._check_test_dependencies()
        self._init_test()

    def _init_test(self):
        self.tmp_fn = 'brain'

    def _port_model(self):
        self.mdl.fit(self.X, self.y)
        subp.call(['rm', '-rf', 'tmp'])
        # $ mkdir tmp
        subp.call(['mkdir', 'tmp'])
        filename = self.tmp_fn + '.c'
        path = os.path.join('tmp', filename)
        with open(path, 'w') as f:
            porter = Porter(self.mdl, language='c')
            out = porter.export(class_name='Brain',
                                method_name='foo')
            f.write(out)
        # $ gcc temp/tmp.c -o temp/tmp
        subp.call(['gcc', path, '-lm', '-o', 'tmp/' + self.tmp_fn])

    def pred_in_py(self, features, cast=True):
        pred = self.mdl.predict([features])[0]
        return int(pred) if cast else float(pred)

    def pred_in_custom(self, features, cast=True):
        # $ <tmp_filename> <features>
        cmd = [os.path.join('.', 'tmp', self.tmp_fn)]
        args = [str(f).strip() for f in features]
        cmd += args
        pred = subp.check_output(cmd, stderr=subp.STDOUT).rstrip()
        return int(pred) if cast else float(pred)
